'* * * * * * * * * * * * * * *
'* AGS_Multi_Clock_V202      *
'* Bryant Griffin            *
'* Avanguard Solutions Inc.  *
'* * * * * * * * * * * * * * *
Option Explicit

Dim iTimerID
Dim numberOfClocks, transitions, dateFormat
Dim showName(7), showDate(7), showSeconds(7), display24Hour(7), clockName(7), timeZoneIndex(7), background(7), flashColon(7)
Dim lCol, lSec, lMin, lHour(7), lAp(7), lDat(7), lDow(7), lMon(7), curTime(7)

System.Gadget.onSettingsClosed = GetRef("SettingsClosed")
System.Gadget.visibilityChanged = GetRef("VisibilityChanged")
System.Gadget.settingsUI = "/AGS_Multi_Clock_V202_Settings.html"
  
'* * * * * * * *
'* Entry Point * 
'* * * * * * * *
Sub StartUp()
  iTimerID = Empty
  Call InitializeDisplay
End Sub

'* * * * *
'* Exit  *
'* * * * *
Sub ShutDown()
  Call StopTimer
End Sub

'* * * * * * * * * * * * * * * * *
'* Refresh After Settings Change *
'* * * * * * * * * * * * * * * * *
Sub SettingsClosed(anEvent)
  If (anEvent.closeAction = anEvent.Action.commit) Then
    Call InitializeDisplay
  End If
End Sub

'* * * * * * * * * * * * * * * * * * * * * * * * * * * *
'* Wait For The Top Of The Second And Start The Timer  *
'* * * * * * * * * * * * * * * * * * * * * * * * * * * *
Sub StartTimer()
  If IsEmpty(iTimerID) Then
    iTimerID = window.setInterval("UpdateDisplay", 500)
  End If
End Sub

'* * * * * * * * * * * * * * * * * *
'* Terminate Timer Before Exiting  *
'* * * * * * * * * * * * * * * * * *
Sub StopTimer()
  If Not(IsEmpty(iTimerID)) Then
    window.clearInterval(iTimerID)
    iTimerID = Empty
  End If
End Sub

'* * * * * * * * * * * * * * * * * * * *
'* Update Only While Gadget Is Visible *
'* * * * * * * * * * * * * * * * * * * *
Sub VisibilityChanged()
  If System.Gadget.visible Then
    Call StartTimer
  Else
    Call StopTimer
  End If
End Sub

'* * * * * * * * * * * * * * * * *
'* Initialize And Build Display  *
'* * * * * * * * * * * * * * * * *
Sub InitializeDisplay()
  Dim idx
  
  Call LoadSettings
  Call SetTransitions
  Call HideInactiveElements
  Call PositionElements()
  
  lCol = 99
  lSec = 99
  lMin = 99
  For idx = 0 To 7
    lHour(idx) = 99
    lAp(idx) = ""
    lDat(idx) = 99
    lDow(idx) = 99
    lMon(idx) = 99
  Next
End Sub

'* * * * * * * * * * * * * * * * *
'* Load Initial Gadget Settings  *
'* * * * * * * * * * * * * * * * *  
Sub LoadSettings()
  If (System.Gadget.Settings.readString ("numberOfClocks") = "") Then
    Call LoadDefaultSettings
  Else
    Call LoadExistingSettings
  End If
End Sub

'* * * * * * * * * * * * * * * * *
'* Load Default Gadget Settings  *
'* * * * * * * * * * * * * * * * *
Sub LoadDefaultSettings()
  Dim setString, idx
  
  System.Gadget.Settings.writeString "numberOfClocks", "4"
  System.Gadget.Settings.writeString "transitions", "True"
  System.Gadget.Settings.writeString "dateFormat", "1"
  
  For idx = 0 To 7
    System.Gadget.Settings.writeString ("showName" + CStr(idx)), "True"
    System.Gadget.Settings.writeString ("showDate" + CStr(idx)), "True"
    System.Gadget.Settings.writeString ("showSeconds" + CStr(idx)), "True"
    System.Gadget.Settings.writeString ("display24Hour" + CStr(idx)), "False"
    System.Gadget.Settings.writeString ("background" + CStr(idx)), LCase(System.Gadget.path + "\images\themes\013.000000.jpg")
    System.Gadget.Settings.writeString ("flashColon" + CStr(idx)), "False"
  Next
    
  System.Gadget.Settings.writeString "clockName0", "Pacific"
  System.Gadget.Settings.writeString "clockName1", "Mountain"
  System.Gadget.Settings.writeString "clockName2", "Central"
  System.Gadget.Settings.writeString "clockName3", "Eastern"
  System.Gadget.Settings.writeString "clockName4", "G.M.T"
  System.Gadget.Settings.writeString "clockName5", "Baghdad"
  System.Gadget.Settings.writeString "clockName6", "New Delhi"
  System.Gadget.Settings.writeString "clockName7", "Tokyo"

  System.Gadget.Settings.writeString "timeZoneIndex0", "61"
  System.Gadget.Settings.writeString "timeZoneIndex1", "50"
  System.Gadget.Settings.writeString "timeZoneIndex2", "21"
  System.Gadget.Settings.writeString "timeZoneIndex3", "29"
  System.Gadget.Settings.writeString "timeZoneIndex4", "35"
  System.Gadget.Settings.writeString "timeZoneIndex5", "4"
  System.Gadget.Settings.writeString "timeZoneIndex6", "40"
  System.Gadget.Settings.writeString "timeZoneIndex7", "76"

  Call LoadExistingSettings
End Sub

'* * * * * * * * *
'* Load Existing *
'* * * * * * * * *
Sub LoadExistingSettings()
  Dim setString, idx

  setString = System.Gadget.Settings.readString("numberOfClocks")
  numberOfClocks = CInt(setString)
  
  setString = System.Gadget.Settings.readString("transitions")
  transitions = CBool(setString)
  
  setString = System.Gadget.Settings.readString("dateFormat")
  dateFormat = setString
  
  For idx = 0 To 7
    setString = System.Gadget.Settings.readString ("showName" + CStr(idx))
    showName(idx) = CBool(setString)
  
    setString = System.Gadget.Settings.readString ("showDate" + CStr(idx))
    showDate(idx) = CBool(setString)
  
    setString = System.Gadget.Settings.readString ("showSeconds" + CStr(idx))
    showSeconds(idx) = CBool(setString)
  
    setString = System.Gadget.Settings.readString ("display24Hour" + CStr(idx))
    display24Hour(idx) = CBool(setString)
  
    setString = System.Gadget.Settings.readString ("clockName" + CStr(idx))
    clockName(idx) = setString

    setString = System.Gadget.Settings.readString ("timeZoneIndex" + CStr(idx))
    timeZoneIndex(idx) = CInt(setString)
  
    setString = System.Gadget.Settings.readString ("background" + CStr(idx))
    background(idx) = setString
    
    setString = System.Gadget.Settings.readString ("flashColon" + CStr(idx))
    flashColon(idx) = CBool(setString)
  Next
End Sub

'* * * * * * * * * * * * * * * * * * * *
'* Enable/Disable Element Ttransitions *
'* * * * * * * * * * * * * * * * * * * *
Sub SetTransitions()
  Dim idx
  
  For idx = 0 To numberOfClocks - 1
    document.getElementById("c_clock" + CStr(idx + 1) + "_hour_border").filters.item("DXImageTransform.Microsoft.Stretch").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_colon_border").filters.item("DXImageTransform.Microsoft.Fade").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_minute_border").filters.item("DXImageTransform.Microsoft.Stretch").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_ampm_border").filters.item("DXImageTransform.Microsoft.Slide").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_second_border").filters.item("DXImageTransform.Microsoft.Fade").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_day_border").filters.item("DXImageTransform.Microsoft.Stretch").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_month_border").filters.item("DXImageTransform.Microsoft.Slide").enabled = transitions
    document.getElementById("c_clock" + CStr(idx + 1) + "_date_border").filters.item("DXImageTransform.Microsoft.Slide").enabled = transitions    
  Next
End Sub

'* * * * * * * * * * * * * * * * * * * * * * * * *
'* Hide Inactive Elements, Show Active Elements  *
'* * * * * * * * * * * * * * * * * * * * * * * * *
Sub HideInactiveElements()
  Dim idx
  
  Call HideAllElements
  
  For idx = 0 To 7
    If (idx < numberOfClocks) Then
      document.getElementById("c_clock" + CStr(idx + 1) + "_background").style.visibility = "visible"
      document.getElementById("c_clock" + CStr(idx + 1) + "_hour_border").style.visibility = "visible"
      document.getElementById("c_clock" + CStr(idx + 1) + "_colon_border").style.visibility = "visible"
      document.getElementById("c_clock" + CStr(idx + 1) + "_minute_border").style.visibility = "visible"

      If showName(idx) Then
        document.getElementById("c_clock" + CStr(idx + 1) + "_name").innerText = clockName(idx)
        document.getElementById("c_clock" + CStr(idx + 1) + "_name_border").style.visibility = "visible"
      End If

      If Not(display24Hour(idx)) Then
        document.getElementById("c_clock" + CStr(idx + 1) + "_ampm_border").style.visibility = "visible"
      End If

      If showSeconds(idx) Then
        document.getElementById("c_clock" + CStr(idx + 1) + "_second_border").style.visibility = "visible"
      End If
    
      If showDate(idx) Then
        If dateFormat = "1" Then
          document.getElementById("c_clock" + CStr(idx + 1) + "_hyphen").innerText ="/"
        Else
          document.getElementById("c_clock" + CStr(idx + 1) + "_hyphen").innerText ="."
        End If
        document.getElementById("c_clock" + CStr(idx + 1) + "_day_border").style.visibility = "visible"
        document.getElementById("c_clock" + CStr(idx + 1) + "_month_border").style.visibility = "visible"
        document.getElementById("c_clock" + CStr(idx + 1) + "_hyphen_border").style.visibility = "visible"
        document.getElementById("c_clock" + CStr(idx + 1) + "_date_border").style.visibility = "visible"
      End If
      Call SetColors(idx)
    End If
  Next
End Sub

'* * * * * * * * * * * * * * * * * * * * *
'* Set Font Colors And Background Image  *
'* * * * * * * * * * * * * * * * * * * * *
Sub SetColors(anIndex)
  Dim color
  
  color = "#" + Split(background(anIndex), ".")(2)
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_background").src = background(anIndex)
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_name").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_hour").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_colon").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_minute").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_ampm").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_second").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_day").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_month").style.color = color
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_hyphen").style.color = color 
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_date").style.color = color
End Sub

'* * * * * * * * * * * * * * * *
'* Initially Hide All Elements *
'* * * * * * * * * * * * * * * *
Sub HideAllElements()
  Dim idx
  
  For idx = 0 To 7
    document.getElementById("c_clock" + CStr(idx + 1) + "_background").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_name_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_hour_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_colon_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_minute_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_ampm_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_second_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_day_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_month_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_hyphen_border").style.visibility = "hidden"
    document.getElementById("c_clock" + CStr(idx + 1) + "_date_border").style.visibility = "hidden"
  Next
End Sub

'* * * * * * * * * * * * * * * *  
'* Position And Size Elements  *
'* * * * * * * * * * * * * * * *
Sub PositionElements()
  Dim idx, gadgetHeight, clockHeight, deltaY
  
  gadgetHeight = 456
  deltaY = 0
  
  For idx = 0 To 7
    If (idx > numberOfClocks - 1) Then
      gadgetHeight = gadgetHeight - 57
    Else
      clockHeight = ResizeClock(idx, deltaY)
      deltaY = deltaY + clockHeight
      gadgetHeight = gadgetHeight - (57 - clockHeight)
    End If
  Next
  document.body.style.height = gadgetHeight
End Sub

'* * * * * * * * * * * * *
'* Size Clock At anIndex *
'* * * * * * * * * * * * *
Function ResizeClock(anIndex, deltaY)
  Dim clockY, clockHeight

  document.getElementById("c_clock" + CStr(anIndex + 1)).style.pixelTop = deltaY
  clockHeight = 57
  
  If (showName(anIndex) And showDate(anIndex)) Then
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hour_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_colon_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_minute_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_ampm_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_second_border").style.top = "26px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_day_border").style.top = "38px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_month_border").style.top = "38px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hyphen_border").style.top = "38px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_date_border").style.top = "38px"
  End If
  
  If (showName(anIndex) And Not(showDate(anIndex))) Then
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hour_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_colon_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_minute_border").style.top = "15px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_ampm_border").style.top = "13px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_second_border").style.top = "24px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_day_border").style.top = "38px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_month_border").style.top = "38px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hyphen_border").style.top = "38px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_date_border").style.top = "38px"
    clockHeight = clockHeight - 14
  End If
  
  If (Not(showName(anIndex)) And showDate(anIndex)) Then
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hour_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_colon_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_minute_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_ampm_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_second_border").style.top = "13px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_day_border").style.top = "25px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_month_border").style.top = "25px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hyphen_border").style.top = "25px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_date_border").style.top = "25px"
    clockHeight = clockHeight - 14
  End If
  
  If (Not(showName(anIndex)) And Not(showDate(anIndex))) Then
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hour_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_colon_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_minute_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_ampm_border").style.top = "1px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_second_border").style.top = "12px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_day_border").style.top = "25px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_month_border").style.top = "25px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_hyphen_border").style.top = "25px"
    document.getElementById("c_clock" + CStr(anIndex + 1) + "_date_border").style.top = "25px"
    clockHeight = clockHeight - 28
  End If

  document.getElementById("c_clock" + CStr(anIndex + 1)).style.height = (CStr(clockHeight) + "px")
  document.getElementById("c_clock" + CStr(anIndex + 1) + "_background").style.height = (CStr(clockHeight - 1) + "px")
    
  ResizeClock = clockHeight 
End Function

'* * * * * * * * * * *
'* Display Elements  *
'* * * * * * * * * * *
Sub UpdateDisplay()
  Dim idx

  If (lCol <> 1) Then
    lCol = 1
    If transitions Then
      For idx = 0 To numberOfClocks - 1
        If flashColon(idx) Then
          document.getElementById("c_clock" + CStr(idx + 1) + "_colon").innerText = ":"
          document.getElementById("c_clock" + CStr(idx + 1) + "_colon_border").filters.item("DXImageTransform.Microsoft.Fade").play
        End If
      Next
    Else
      For idx = 0 To numberOfClocks - 1
        If (flashColon(idx) Or ((document.getElementById("c_clock" + CStr(idx + 1) + "_colon").innerText) = " ")) Then
          document.getElementById("c_clock" + CStr(idx + 1) + "_colon").innerText = ":"
        End If
      Next
    End If
    Call UpdateSecond
  Else
    lCol = 0
    If Not(transitions) Then
      For idx = 0 To numberOfClocks - 1
        If flashColon(idx) Then
          document.getElementById("c_clock" + CStr(idx + 1) + "_colon").innerText = " "
        End If
      Next
    End If
  End If
End Sub

'* * * * * * * * * *
'* Display Seconds *
'* * * * * * * * * *
Sub UpdateSecond()
  Dim cSec, idx
  
  For idx = 0 To numberOfClocks - 1
    curTime(idx) = getTimeForZone(timeZoneIndex(idx))
  Next
  
  cSec = Second(Now)
  If (cSec <> lSec) Then
    lSec = cSec
    For idx = 0 To numberOfClocks - 1   
      If showSeconds(idx) Then
         document.getElementById("c_clock" + CStr(idx + 1) + "_second").innerText = Padded(cSec)
         If transitions Then
           document.getElementById("c_clock" + CStr(idx + 1) + "_second_border").filters.item("DXImageTransform.Microsoft.Fade").play
         End If
      End If
    Next
    Call UpdateMinute
  End If
End Sub

'* * * * * * * * * *
'* Display Minutes *
'* * * * * * * * * *
Sub UpdateMinute()
  Dim cMin, idx
  
  cMin = Minute(curTime(0))
  If (cMin <> lMin) Then
    lMin = cMin
    For idx = 0 To numberOfClocks - 1
      cMin = Minute(curTime(idx))
      
      If transitions Then
        document.getElementById("c_clock" + CStr(idx + 1) + "_minute_border").filters.item("DXImageTransform.Microsoft.Stretch").apply
        document.getElementById("c_clock" + CStr(idx + 1) + "_minute").innerText = Padded(cMin)
        document.getElementById("c_clock" + CStr(idx + 1) + "_minute_border").filters.item("DXImageTransform.Microsoft.Stretch").play
      Else
        document.getElementById("c_clock" + CStr(idx + 1) + "_minute").innerText = Padded(cMin)      
      End If
    Next
    Call UpdateHour
  End If
End Sub

'* * * * * * * * *
'* Display Hours *
'* * * * * * * * *
Sub UpdateHour()
  Dim updated, cHour, idx

  updated = false
  For idx = 0 To numberOfClocks - 1
    cHour = Hour(curTime(idx))
    If (cHour <> lHour(idx)) Then
      lHour(idx) = cHour 
      If Not(display24Hour(idx)) Then
        cHour = cHour Mod 12
        If cHour = 0 Then
          cHour = 12
        End If
      End If
      If transitions Then
        document.getElementById("c_clock" + CStr(idx + 1) + "_hour_border").filters.item("DXImageTransform.Microsoft.Stretch").apply
        document.getElementById("c_clock" + CStr(idx + 1) + "_hour").innerText = CStr(cHour)
        document.getElementById("c_clock" + CStr(idx + 1) + "_hour_border").filters.item("DXImageTransform.Microsoft.Stretch").play
      Else
        document.getElementById("c_clock" + CStr(idx + 1) + "_hour").innerText = CStr(cHour)      
      End If
      updated = true
    End If
  Next  
  If updated Then
  Call UpdateAP
  End If
End Sub

'* * * * * * * * * * * * * *
'* Display AM-PM Indicator *
'* * * * * * * * * * * * * *
Sub UpdateAP()
  Dim cAp, idx

  For idx = 0 To numberOfClocks - 1
    If Not(display24Hour(idx)) Then
      If Hour(curTime(idx)) < 12 Then
        cAp = "AM"
      Else
        cAp = "PM"
      End If
      
      If (cAp <> lAp(idx)) Then
        lAp(idx) = cAp
        If transitions Then
          document.getElementById("c_clock" + CStr(idx + 1) + "_ampm_border").filters.item("DXImageTransform.Microsoft.Slide").apply
          document.getElementById("c_clock" + CStr(idx + 1) + "_ampm").innerText = cAp
          document.getElementById("c_clock" + CStr(idx + 1) + "_ampm_border").filters.item("DXImageTransform.Microsoft.Slide").play
        Else
          document.getElementById("c_clock" + CStr(idx + 1) + "_ampm").innerText = cAp      
        End If
      End If
    End If
  Next
  Call UpdateDate
End Sub

'* * * * * * * * *
'* Display Date  *
'* * * * * * * * *
Sub UpdateDate()
  Dim cDat, updated, idx, theElement, theBorder
  
  updated = false
  For idx = 0 To numberOfClocks - 1
    If showDate(idx) Then
      cDat = Day(curTime(idx))
      If (cDat <> lDat(idx)) Then
        lDat(idx) = cDat
        
        If dateFormat = "1" Then
          Set theBorder = document.getElementById("c_clock" + CStr(idx + 1) + "_date_border")
          Set theElement = document.getElementById("c_clock" + CStr(idx + 1) + "_date")
        Else
          Set theBorder = document.getElementById("c_clock" + CStr(idx + 1) + "_month_border")
          Set theElement = document.getElementById("c_clock" + CStr(idx + 1) + "_month")
        End If
        
        If transitions Then
          theBorder.filters.item("DXImageTransform.Microsoft.Slide").apply
          theElement.innerText = Padded(cDat)
          theBorder.filters.item("DXImageTransform.Microsoft.Slide").play
        Else
          theElement.innerText = Padded(cDat)      
        End If
        updated = true
      End If
    End If
  Next
  If updated then
    Call UpdateDay
  End If
End Sub

'* * * * * * * * * * * *
'* Display Day Of Week *
'* * * * * * * * * * * *
Sub UpdateDay()
  Dim cDow, idx
  
  For idx = 0 To numberOfClocks - 1
    If showDate(idx) Then
      cDow = Weekday(curTime(idx))
      If (cDow <> lDow(idx)) Then
        lDow(idx) = cDow
        If transitions Then
          document.getElementById("c_clock" + CStr(idx + 1) + "_day_border").filters.item("DXImageTransform.Microsoft.Stretch").apply
          document.getElementById("c_clock" + CStr(idx + 1) + "_day").innerText = WeekDayName(cDow)
          document.getElementById("c_clock" + CStr(idx + 1) + "_day_border").filters.item("DXImageTransform.Microsoft.Stretch").play
        Else
          document.getElementById("c_clock" + CStr(idx + 1) + "_day").innerText = WeekDayName(cDow)
        End If
      End If
    End If
  Next
  Call UpdateMonth
End Sub

'* * * * * * * * *
'* Display Month *
'* * * * * * * * *
Sub UpdateMonth()
  Dim cMon, idx, theElement, theBorder

  For idx = 0 To numberOfClocks - 1
    If showDate(idx) Then
      cMon = Month(curTime(idx))
      If (cMon <> lMon(idx)) Then
        lMon(idx) = cMon
        
        If dateFormat = "1" Then
          Set theBorder = document.getElementById("c_clock" + CStr(idx + 1) + "_month_border")
          Set theElement = document.getElementById("c_clock" + CStr(idx + 1) + "_month")
        Else
          Set theBorder = document.getElementById("c_clock" + CStr(idx + 1) + "_date_border")
          Set theElement = document.getElementById("c_clock" + CStr(idx + 1) + "_date")
        End If

        If transitions Then
          theBorder.filters.item("DXImageTransform.Microsoft.Slide").apply
          theElement.innerText = Padded(cMon)
          theBorder.filters.item("DXImageTransform.Microsoft.Slide").play
        Else
          theElement.innerText = Padded(cMon)      
        End If
      End If
    End If
  Next
End Sub

'* * * * * * * * * * * * * * * * * * * * * * * * *
'* Return Value As A 2-Digit Zero Padded String  *
'* * * * * * * * * * * * * * * * * * * * * * * * *
Function Padded(aValue)
  Dim result
  
  result = CStr(aValue)
  If Len(result) < 2 Then
    result = "0" + result
  End If
  Padded = result
End Function

'* * * * * * * * * * * * *
'* Show Movement Buttons *
'* * * * * * * * * * * * *
Sub ShowButtons(anIndex)
  Dim upElement, downElement, buttonElement

  Set upElement = document.getElementById("c_clock" + CStr(anIndex) + "_up_button")
  Set downElement = document.getElementById("c_clock" + CStr(anIndex) + "_down_button")
  Set buttonElement = document.getElementById("c_clock" + CStr(anIndex) + "_buttons")

  buttonElement.filters.blendTrans.apply()
  
  buttonElement.style.visibility = "visible"
  If (anIndex > 1) Then
    upElement.style.visibility = "visible"
  End If
  If (anIndex < numberOfClocks) Then
    downElement.style.visibility = "visible"
  End If

  buttonElement.filters.blendTrans.play()
End Sub

'* * * * * * * * * * * * *
'* Hide Movement Buttons *
'* * * * * * * * * * * * *
Sub HideButtons(anIndex)
  Dim upElement, downElement, buttonElement

  Set upElement = document.getElementById("c_clock" + CStr(anIndex) + "_up_button")
  Set downElement = document.getElementById("c_clock" + CStr(anIndex) + "_down_button")
  Set buttonElement = document.getElementById("c_clock" + CStr(anIndex) + "_buttons")
  
  buttonElement.filters.blendTrans.apply()

  upElement.style.visibility = "hidden"
  downElement.style.visibility = "hidden"
  buttonElement.style.visibility = "hidden"

  buttonElement.filters.blendTrans.play()
End Sub

'* * * * * * * * * * * * * * *
'* Move Clock At anIndex Up  *
'* * * * * * * * * * * * * * *
Sub MoveUp(anIndex)
  Call MoveClock(anIndex - 1, -1)
End Sub

'* * * * * * * * * * * * * * * *
'* Move Clock At anIndex Down  *
'* * * * * * * * * * * * * * * *
Sub MoveDown(anIndex)
  Call MoveClock(anIndex - 1, +1)
End Sub

'* * * * * * * * * * * * * *
'* Move A Clock Up Or Down *
'* * * * * * * * * * * * * *
Sub MoveClock(anIndex, aDirection)
  Dim temp

  Call StopTimer

  temp = showName(anIndex + aDirection)
  showName(anIndex + aDirection) = showName(anIndex)
  showName(anIndex) = temp

  temp = showDate(anIndex + aDirection)
  showDate(anIndex + aDirection) = showDate(anIndex)
  showDate(anIndex) = temp

  temp = showSeconds(anIndex + aDirection)
  showSeconds(anIndex + aDirection) = showSeconds(anIndex)
  showSeconds(anIndex) = temp

  temp = display24Hour(anIndex + aDirection)
  display24Hour(anIndex + aDirection) = display24Hour(anIndex)
  display24Hour(anIndex) = temp
  
  temp = flashColon(anIndex + aDirection)
  flashColon(anIndex + aDirection) = flashColon(anIndex)
  flashColon(anIndex) = temp

  temp = clockName(anIndex + aDirection)
  clockName(anIndex + aDirection) = clockName(anIndex)
  clockName(anIndex) = temp

  temp = timeZoneIndex(anIndex + aDirection)
  timeZoneIndex(anIndex + aDirection) = timeZoneIndex(anIndex)
  timeZoneIndex(anIndex) = temp

  temp = background(anIndex + aDirection)
  background(anIndex + aDirection) = background(anIndex)
  background(anIndex) = temp

  System.Gadget.Settings.writeString ("showName" + CStr(anIndex)), CStr(showName(anIndex))
  System.Gadget.Settings.writeString ("showDate" + CStr(anIndex)), CStr(showDate(anIndex))
  System.Gadget.Settings.writeString ("showSeconds" + CStr(anIndex)), CStr(showSeconds(anIndex))
  System.Gadget.Settings.writeString ("display24Hour" + CStr(anIndex)), CStr(display24Hour(anIndex))
  System.Gadget.Settings.writeString ("flashColon" + CStr(anIndex)), CStr(flashColon(anIndex))
  System.Gadget.Settings.writeString ("clockName" + CStr(anIndex)), clockName(anIndex)
  System.Gadget.Settings.writeString ("timeZoneIndex" + CStr(anIndex)), CStr(timeZoneIndex(anIndex))
  System.Gadget.Settings.writeString ("background" + CStr(anIndex)), background(anIndex)

  System.Gadget.Settings.writeString ("showName" + CStr(anIndex + aDirection)), CStr(showName(anIndex + aDirection))
  System.Gadget.Settings.writeString ("showDate" + CStr(anIndex + aDirection)), CStr(showDate(anIndex + aDirection))
  System.Gadget.Settings.writeString ("showSeconds" + CStr(anIndex + aDirection)), CStr(showSeconds(anIndex + aDirection))
  System.Gadget.Settings.writeString ("display24Hour" + CStr(anIndex + aDirection)), CStr(display24Hour(anIndex + aDirection))
  System.Gadget.Settings.writeString ("flashColon" + CStr(anIndex + aDirection)), CStr(flashColon(anIndex + aDirection))
  System.Gadget.Settings.writeString ("clockName" + CStr(anIndex + aDirection)), clockName(anIndex + aDirection)
  System.Gadget.Settings.writeString ("timeZoneIndex" + CStr(anIndex + aDirection)), CStr(timeZoneIndex(anIndex + aDirection))
  System.Gadget.Settings.writeString ("background" + CStr(anIndex + aDirection)), background(anIndex + aDirection)

  Call InitializeDisplay

  Call StartTimer
End Sub
